@@ -192,6 +192,7 @@ e_data_book_status_to_string (EDataBookStatus status)
 		{ E_DATA_BOOK_STATUS_INVALID_SERVER_VERSION,		N_("Invalid server version") },
 		{ E_DATA_BOOK_STATUS_NO_SPACE,				N_("No space") },
 		{ E_DATA_BOOK_STATUS_INVALID_ARG,			N_("Invalid argument") },
+		/* Translators: The string for NOT_SUPPORTED error */
 		{ E_DATA_BOOK_STATUS_NOT_SUPPORTED,			N_("Not supported") }
 	};
 
@@ -207,7 +208,7 @@ e_data_book_status_to_string (EDataBookStatus status)
 GQuark
 e_data_book_error_quark (void)
 {
-	#define ERR_PREFIX "org.gnome.evolution.dataserver.addressbook.Book."
+	#define ERR_PREFIX "org.gnome.evolution.dataserver.AddressBook."
 
 	static const GDBusErrorEntry entries[] = {
 		{ E_DATA_BOOK_STATUS_SUCCESS,				ERR_PREFIX "Success" },
@@ -644,7 +645,7 @@ construct_bookview_path (void)
 {
 	static volatile guint counter = 1;
 
-	return g_strdup_printf ("/org/gnome/evolution/dataserver/addressbook/BookView/%d/%d",
+	return g_strdup_printf ("/org/gnome/evolution/dataserver/AddressBookView/%d/%d",
 				getpid (),
 				g_atomic_int_exchange_and_add ((int*)&counter, 1));
 }
@@ -849,7 +850,8 @@ e_data_book_init (EDataBook *ebook)
 {
 	EGdbusBook *gdbus_object;
 
-	ebook->priv = G_TYPE_INSTANCE_GET_PRIVATE (ebook, E_TYPE_DATA_BOOK, EDataBookPrivate);
+	ebook->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		ebook, E_TYPE_DATA_BOOK, EDataBookPrivate);
 
 	ebook->priv->gdbus_object = e_gdbus_book_stub_new ();
 
