@@ -30,10 +30,6 @@
 #include "camel-mime-filter-enriched.h"
 #include "camel-string-utils.h"
 
-#define CAMEL_MIME_FILTER_ENRICHED_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_MIME_FILTER_ENRICHED, CamelMimeFilterEnrichedPrivate))
-
 struct _CamelMimeFilterEnrichedPrivate {
 	guint32 flags;
 	gint nofill;
@@ -228,7 +224,7 @@ enriched_to_html (CamelMimeFilter *mime_filter,
 	register const gchar *inptr;
 	register gchar *outptr;
 
-	priv = CAMEL_MIME_FILTER_ENRICHED_GET_PRIVATE (mime_filter);
+	priv = CAMEL_MIME_FILTER_ENRICHED (mime_filter)->priv;
 
 	camel_mime_filter_set_size (mime_filter, inlen * 2 + 6, FALSE);
 
@@ -519,7 +515,7 @@ mime_filter_enriched_reset (CamelMimeFilter *mime_filter)
 {
 	CamelMimeFilterEnrichedPrivate *priv;
 
-	priv = CAMEL_MIME_FILTER_ENRICHED_GET_PRIVATE (mime_filter);
+	priv = CAMEL_MIME_FILTER_ENRICHED (mime_filter)->priv;
 
 	priv->nofill = 0;
 }
@@ -549,7 +545,9 @@ camel_mime_filter_enriched_class_init (CamelMimeFilterEnrichedClass *class)
 static void
 camel_mime_filter_enriched_init (CamelMimeFilterEnriched *filter)
 {
-	filter->priv = CAMEL_MIME_FILTER_ENRICHED_GET_PRIVATE (filter);
+	filter->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		filter, CAMEL_TYPE_MIME_FILTER_ENRICHED,
+		CamelMimeFilterEnrichedPrivate);
 }
 
 /**
@@ -564,15 +562,15 @@ camel_mime_filter_enriched_init (CamelMimeFilterEnriched *filter)
 CamelMimeFilter *
 camel_mime_filter_enriched_new (guint32 flags)
 {
-	CamelMimeFilter *new;
+	CamelMimeFilter *res;
 	CamelMimeFilterEnrichedPrivate *priv;
 
-	new = g_object_new (CAMEL_TYPE_MIME_FILTER_ENRICHED, NULL);
-	priv = CAMEL_MIME_FILTER_ENRICHED_GET_PRIVATE (new);
+	res = g_object_new (CAMEL_TYPE_MIME_FILTER_ENRICHED, NULL);
+	priv = CAMEL_MIME_FILTER_ENRICHED (res)->priv;
 
 	priv->flags = flags;
 
-	return new;
+	return res;
 }
 
 /**
