@@ -36,13 +36,8 @@
 #include "camel-nntp-folder.h"
 #include "camel-nntp-private.h"
 #include "camel-nntp-store.h"
-#include "camel-nntp-store.h"
 #include "camel-nntp-summary.h"
 
-#define CAMEL_NNTP_FOLDER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_NNTP_FOLDER, CamelNNTPFolderPrivate))
-
 G_DEFINE_TYPE (CamelNNTPFolder, camel_nntp_folder, CAMEL_TYPE_DISCO_FOLDER)
 
 static void
@@ -521,7 +516,7 @@ nntp_folder_append_message_online (CamelFolder *folder,
 	    || camel_data_wrapper_write_to_stream_sync (CAMEL_DATA_WRAPPER (mime_message), filtered_stream, cancellable, error) == -1
 	    || camel_stream_flush (filtered_stream, cancellable, error) == -1
 	    || camel_stream_write (stream, "\r\n.\r\n", 5, cancellable, error) == -1
-	    || (ret = camel_nntp_stream_line (nntp_store->stream, (guchar **)&line, &u, cancellable, error)) == -1) {
+	    || camel_nntp_stream_line (nntp_store->stream, (guchar **)&line, &u, cancellable, error) == -1) {
 		g_prefix_error (error, _("Posting failed: "));
 		success = FALSE;
 	} else if (atoi (line) != 240) {
@@ -576,6 +571,32 @@ nntp_folder_transfer_message (CamelFolder *source,
 	return FALSE;
 }
 
+static gboolean
+nntp_folder_expunge_uids_offline (CamelFolder *folder, GPtrArray *uids, GError **error)
+{
+	CamelFolderChangeInfo *changes;
+	gint ii;
+
+	g_return_val_if_fail (folder != NULL, FALSE);
+	g_return_val_if_fail (CAMEL_IS_NNTP_FOLDER (folder), FALSE);
+	g_return_val_if_fail (uids != NULL, FALSE);
+	g_return_val_if_fail (folder->summary != NULL, FALSE);
+
+	/* can only remove deleted messages from a local cache */
+
+	changes = camel_folder_change_info_new ();
+	for (ii = 0; ii < uids->len; ii++) {
+		camel_folder_summary_remove_uid (folder->summary, uids->pdata[ii]);
+		camel_folder_change_info_remove_uid (changes, uids->pdata[ii]);
+	}
+
+	camel_folder_summary_save_to_db (folder->summary, NULL);
+	camel_folder_changed (folder, changes);
+	camel_folder_change_info_free (changes);
+
+	return TRUE;
+}
+
 static void
 camel_nntp_folder_class_init (CamelNNTPFolderClass *class)
 {
@@ -609,12 +630,16 @@ camel_nntp_folder_class_init (CamelNNTPFolderClass *class)
 	disco_folder_class->transfer_resyncing = nntp_folder_transfer_message;
 	disco_folder_class->transfer_offline = nntp_folder_transfer_message;
 	disco_folder_class->refresh_info_online = nntp_folder_refresh_info_online;
+	disco_folder_class->expunge_uids_online = nntp_folder_expunge_uids_offline;
+	disco_folder_class->expunge_uids_offline = nntp_folder_expunge_uids_offline;
+	disco_folder_class->expunge_uids_resyncing = nntp_folder_expunge_uids_offline;
 }
 
 static void
 camel_nntp_folder_init (CamelNNTPFolder *nntp_folder)
 {
-	nntp_folder->priv = CAMEL_NNTP_FOLDER_GET_PRIVATE (nntp_folder);
+	nntp_folder->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		nntp_folder, CAMEL_TYPE_NNTP_FOLDER, CamelNNTPFolderPrivate);
 
 	nntp_folder->changes = camel_folder_change_info_new ();
 	nntp_folder->priv->search_lock = g_mutex_new ();
@@ -675,7 +700,7 @@ camel_nntp_folder_new (CamelStore *parent,
 			folder, cancellable, error)) {
 		g_object_unref (folder);
 		folder = NULL;
-        }
+	}
 
 	return folder;
 }
